@@ -11,7 +11,7 @@ n = 100_000
 
 Benchmark.bmbm do |x|
   x.report "jaro_winkler (#{`git rev-parse --short HEAD`.chop!})" do
-    n.times { SAMPLES[:ascii].each { |str1, str2| JaroWinkler.distance(str1, str2) } }
+    n.times { SAMPLES[:ascii].each { |str1, str2| JaroWinkler.similarity(str1, str2) } }
   end
 
   x.report gem_name_with_version('fuzzy-string-match') do
